@@ -1,11 +1,6 @@
-/**
- * Copyright (C) 2015 Deepin Technology Co., Ltd.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
- **/
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 package main
 
 import (
@@ -302,13 +297,15 @@ func (this *binding_generator) c_forward_declaration10(bi *gi.BaseInfo) {
 		pc := printer_to(this.out_c)
 		ctype := c_type_for_interface(bi, type_none)
 
+		ci := gi.ToCallableInfo(bi)
+
 		// type doesn't matter here, it's just a pointer after all
 		p("typedef void* %s;\n", ctype)
 
 		// and wrapper declarations for .c file only (cgo has problems
 		// with that)
-		pc("extern void _%s_c_wrapper();\n", ctype)
-		pc("extern void _%s_c_wrapper_once();\n", ctype)
+		pc("extern %s _%s_c_wrapper();\n", c_type(ci.ReturnType(), type_none), ctype)
+		pc("extern %s _%s_c_wrapper_once();\n", c_type(ci.ReturnType(), type_none), ctype)
 	}
 }
 
