@@ -1,14 +1,19 @@
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 package main
 
 import (
-	"pkg.deepin.io/gir/gio-2.0"
+	"fmt"
+	"os"
 	"runtime"
 	"strings"
+	"syscall"
+	"time"
+
+	"github.com/linuxdeepin/go-gir/gio-2.0"
 )
-import "time"
-import "syscall"
-import "fmt"
-import "os"
 
 func RSSinMB() int {
 	var r syscall.Rusage
@@ -26,8 +31,8 @@ func TestFunc() {
 }
 
 func main() {
-	var limit = 30
-	if strings.HasPrefix(runtime.GOARCH, "arm") {
+	var limit = 60
+	if strings.HasPrefix(runtime.GOARCH, "arm") { // 易阻塞CRP打包，只在本地进行测试
 		// GOARCH is arm or arm64
 		limit = 200
 	}
@@ -37,7 +42,7 @@ func main() {
 	baseRSSinMB := RSSinMB()
 	fmt.Printf("base: %dMB\n", baseRSSinMB)
 	getIncreased := func() int {
-		return  RSSinMB() - baseRSSinMB
+		return RSSinMB() - baseRSSinMB
 	}
 
 	time.AfterFunc(time.Second*60, func() {
